Contract class

Available extensions
Annotations
  • @freezed

Constructors

Contract({required String? bytecode, required ContractManifest manifest})
const
factory
Contract.fromJson(Map<String, dynamic> json)
factory

Properties

bytecode String?
no setterinherited
copyWith → $ContractCopyWith<Contract>
Create a copy of Contract with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
manifest ContractManifest
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractActionsFromContract(String code) List<ContractAction>

Available on Contract, provided by the ContractUtils extension

getActions() List<ContractAction>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseTypedArgument(dynamic input) → dynamic

Available on Contract, provided by the ContractUtils extension

toJson() Map<String, dynamic>
Serializes this Contract to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
updateContractTransaction(String contractAddress) → void

Available on Contract, provided by the ContractUtils extension

Operators

operator ==(Object other) bool
The equality operator.
inherited