AesEncAlgorithms class

Inheritance

Constructors

AesEncAlgorithms()

Properties

cbc → AlgorithmIdentifier<PaddedBlockCipherImpl>
AES CBC
final
cbcWithHmac → AesWithHmacEncAlgorithms
final
eax → AlgorithmIdentifier<Never>
AES EAX
final
gcm → AlgorithmIdentifier<GCMBlockCipher>
AES GCM
final
hashCode → int
The hash code for this object.
no setterinherited
keyWrap → AlgorithmIdentifier<AESKeyWrap>
AES Key Wrap with default initial value
final
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited