AesWithHmacEncAlgorithms class

Inheritance

Constructors

AesWithHmacEncAlgorithms()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256 → AlgorithmIdentifier<AesCbcAuthenticatedCipherWithHash>
AES_128_CBC_HMAC_SHA_256 authenticated encryption algorithm
final
sha384 → AlgorithmIdentifier<AesCbcAuthenticatedCipherWithHash>
AES_192_CBC_HMAC_SHA_384 authenticated encryption algorithm
final
sha512 → AlgorithmIdentifier<AesCbcAuthenticatedCipherWithHash>
AES_256_CBC_HMAC_SHA_512 authenticated encryption algorithm
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited