AlgorithmIdentifier<T extends Algorithm> class

Inheritance

Properties

factory → T Function()
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAlgorithm() → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getByJwaName(String alg) → AlgorithmIdentifier<Algorithm>?