EncAlgorithms class

Inheritance

Constructors

EncAlgorithms()

Properties

aes → AesEncAlgorithms
Contains the identifiers for supported AES encryption algorithms
final
hashCode → int
The hash code for this object.
no setterinherited
hybrid → HybridEncAlgorithms
Contains the identifiers for supported hybrid encryption algorithms
final
name → String
finalinherited
rsa → _RsaEncAlgorithms
Contains the identifiers for supported RSA encryption algorithms
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited