EcPrivateKeyImpl class

Inheritance
Implemented types
Mixed-in types

Constructors

EcPrivateKeyImpl({required BigInt eccPrivateKey, required Identifier curve})

Properties

curve → Identifier
The cryptographic curve used with the key
final
eccPrivateKey → BigInt
The Elliptic Curve private key value
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createEncrypter(Identifier algorithm) → Encrypter<Key>
Creates an Encrypter using this key and the specified algorithm
inherited
createSigner(Identifier algorithm) → Signer<PrivateKey>
Creates a Signer using this key and the specified algorithm.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override