EcPublicKeyImpl class

Inheritance
Implemented types
Mixed-in types

Constructors

EcPublicKeyImpl({required BigInt xCoordinate, required BigInt yCoordinate, required Identifier curve})

Properties

curve → Identifier
The cryptographic curve used with the key
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xCoordinate → BigInt
The x coordinate for the Elliptic Curve point
final
yCoordinate → BigInt
The y coordinate for the Elliptic Curve point
final

Methods

createEncrypter(Identifier algorithm) → Encrypter<Key>
Creates an Encrypter using this key and the specified algorithm
inherited
createVerifier(Identifier algorithm) → Verifier<PublicKey>
Creates a signature Verifier using this key and the specified algorithm
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override