EncryptionResultImpl class

Implemented types

Constructors

EncryptionResultImpl(Uint8List data, {Uint8List? initializationVector, Uint8List? authenticationTag, Uint8List? additionalAuthenticatedData})

Properties

additionalAuthenticatedData → Uint8List?
final
authenticationTag → Uint8List?
final
data → Uint8List
Byte representation of the ciphertext
final
hashCode → int
The hash code for this object.
no setteroverride
initializationVector → Uint8List?
The initialization vector used for encrypting when required by the algorithm
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override