RsaPublicKeyImpl class

Inheritance
Implemented types
Mixed-in types

Constructors

RsaPublicKeyImpl({required BigInt modulus, required BigInt exponent})

Properties

exponent → BigInt
The exponent value for the RSA public key
final
hashCode → int
The hash code for this object.
no setteroverride
modulus → BigInt
The modulus value for the RSA key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createEncrypter(Identifier algorithm) → Encrypter<Key>
Creates an Encrypter using this key and the specified algorithm
inherited
createVerifier(Identifier algorithm) → Verifier<PublicKey>
Creates a signature Verifier using this key and the specified algorithm
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override