SymmetricKeyImpl class

Implemented types
Mixed-in types

Constructors

SymmetricKeyImpl({required Uint8List keyValue})

Properties

hashCode → int
The hash code for this object.
no setteroverride
keyValue → Uint8List
The value of the symmetric (or other single-valued) key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createEncrypter(Identifier algorithm) → Encrypter<Key>
Creates an Encrypter using this key and the specified algorithm
inherited
createSigner(Identifier algorithm) → Signer<PrivateKey>
Creates a Signer using this key and the specified algorithm.
inherited
createVerifier(Identifier algorithm) → Verifier<PublicKey>
Creates a signature Verifier using this key and the specified algorithm
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override