ConsumedInputs constructor
const
ConsumedInputs({})
Implementation
const factory ConsumedInputs({
/// Asset amount
int? amount,
/// Transaction which send the amount of assets
String? from,
/// Address of the token if the type is token
String? tokenAddress,
/// Date time when the UTXO created/manipulated
int? timestamp,
/// Type of input : UCO/token/state/call
String? type,
/// Id for a token which is allocated when the token is minted.
int? tokenId,
/// Version of the UTXO data structure
int? protocolVersion,
/// State of a smart contract
String? state,
}) = _ConsumedInputs;